# pydungeoncrawl

A python package to run a dungeon crawl with appropriate classes and structure.

This package is meant to be used in an interactive session, and works best when used in conjuction with a Jupyter Notebook. It is also useable in Google Colab (with slight modifications to the colab runtime -- for example code see the [API reference](https://dungeon.pynight.com/api)).

## API Reference
See the [API reference](https://dungeon.pynight.com/api) for explanations and usage examples.